@@ -1,3 +1,3 @@
-METHODS_WITH_BODY = set(("POST", "PUT", "DELETE", "PATCH"))
+METHODS_WITH_BODY = set(("GET", "HEAD", "POST", "PUT", "DELETE", "PATCH"))
 STATUS_CODES_WITH_NO_BODY = set((100, 101, 102, 103, 204, 304))
 REF_PREFIX = "#/components/schemas/"
